# eric7.QScintilla.Lexers.LexerVHDL

Module implementing a VHDL lexer with some additional methods.

### Global Attributes

None

### Classes

LexerVHDL | Subclass to implement some additional lexer dependant methods.

### Functions

None

## LexerVHDL

Subclass to implement some additional lexer dependant methods.

### Derived from

Lexer, QsciLexerVHDL

### Class Attributes

None

### Class Methods

None

### Methods

LexerVHDL | Constructor
defaultKeywords | Public method to get the default keywords.
initProperties | Public slot to initialize the properties.
isCommentStyle | Public method to check, if a style is a comment style.
isStringStyle | Public method to check, if a style is a string style.
maximumKeywordSet | Public method to get the maximum keyword set.

### Static Methods

None

#### LexerVHDL (Constructor)

LexerVHDL(parent=None)

Constructor

parent
  parent widget of this lexer

#### LexerVHDL.defaultKeywords

defaultKeywords(kwSet)

Public method to get the default keywords.

kwSet
  number of the keyword set (integer)

Return:
  string giving the keywords (string) or None

#### LexerVHDL.initProperties

initProperties()

Public slot to initialize the properties.

#### LexerVHDL.isCommentStyle

isCommentStyle(style)

Public method to check, if a style is a comment style.

style
  style to check (integer)

Return:
  flag indicating a comment style (boolean)

#### LexerVHDL.isStringStyle

isStringStyle(style)

Public method to check, if a style is a string style.

style
  style to check (integer)

Return:
  flag indicating a string style (boolean)

#### LexerVHDL.maximumKeywordSet

maximumKeywordSet()

Public method to get the maximum keyword set.

Return:
  maximum keyword set (integer)

Up